@@ -297,7 +297,7 @@ gphtextnl(FILE *fp, const char *s, size_t len)
 {
 	size_t i, n = 0;
 
-	for (i = 0; *s && i < len; i++) {
+	for (i = 0; s[i] && i < len; i++) {
 		if (s[i] == '\n')
 			n = 0;
 
@@ -323,8 +323,8 @@ gphtext(FILE *fp, const char *s, size_t len)
 {
 	size_t i;
 
-	for (i = 0; *s && i < len; i++) {
-		switch (s[i]) {
+	for (i = 0; *s && i < len; s++, i++) {
+		switch (*s) {
 		case '\r': /* ignore CR */
 		case '\n': /* ignore LF */
 			break;
@@ -332,7 +332,7 @@ gphtext(FILE *fp, const char *s, size_t len)
 			fputs("        ", fp);
 			break;
 		default:
-			fputc(s[i], fp);
+			fputc(*s, fp);
 			break;
 		}
 	}
@@ -344,8 +344,8 @@ gphlink(FILE *fp, const char *s, size_t len)
 {
 	size_t i;
 
-	for (i = 0; *s && i < len; i++) {
-		switch (s[i]) {
+	for (i = 0; *s && i < len; s++, i++) {
+		switch (*s) {
 		case '\r': /* ignore CR */
 		case '\n': /* ignore LF */
 			break;
@@ -356,7 +356,7 @@ gphlink(FILE *fp, const char *s, size_t len)
 			fputs("\\|", fp);
 			break;
 		default:
-			fputc(s[i], fp);
+			fputc(*s, fp);
 			break;
 		}
 	}
